@@ -129,7 +129,9 @@ groups['가'] = [
         rules = [(u'가', COND_V_ALL, '')],
         after = ['#명사', '#대명사',
                  '#특수:숫자', '#특수:알파벳',
-                 '#특수:수:1', '#특수:수:10', '#특수:수:100', '#특수:수:1000'],
+                 '#특수:수:1', '#특수:수:10', '#특수:수:100', '#특수:수:1000',
+                 '#특수:고유수:1', '#특수:고유수:10',
+                 ],
         notafter = [('나', '#대명사'),
                     ('너', '#대명사'),
                     ('저', '#대명사'),
@@ -204,7 +206,9 @@ groups['!보조사'] = [
         after = ['#부사',
                  '#명사', '#대명사', '#수사',
                  '#특수:숫자', '#특수:알파벳',
-                 '#특수:수:1', '#특수:수:10', '#특수:수:100', '#특수:수:1000'],
+                 '#특수:수:1', '#특수:수:10', '#특수:수:100', '#특수:수:1000',
+                 '#특수:고유수:1', '#특수:고유수:10',
+                 ],
     ),
 ]
 
@@ -337,7 +341,9 @@ groups['*'] = [
          ],
         after = ['#명사', '#대명사', '#수사',
                  '#특수:숫자', '#특수:알파벳',
-                 '#특수:수:1', '#특수:수:10', '#특수:수:100', '#특수:수:1000'],
+                 '#특수:수:1', '#특수:수:10', '#특수:수:100', '#특수:수:1000',
+                 '#특수:고유수:1', '#특수:고유수:10',
+                 ],
     ),
 ]
 
